aboutsummaryrefslogtreecommitdiff
path: root/src/include/taler_merchantdb_plugin.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2021-06-16 22:14:35 +0200
committerChristian Grothoff <christian@grothoff.org>2021-06-16 22:14:35 +0200
commit23b4c5eb9d830fa272c8011b62ac20ef7749f246 (patch)
tree84526f5861abed96e18d0fd32a6b740a7615c75b /src/include/taler_merchantdb_plugin.h
parent1fa773793b24285205818c21c70fb72cd63fe6ba (diff)
fixing #6903
Diffstat (limited to 'src/include/taler_merchantdb_plugin.h')
-rw-r--r--src/include/taler_merchantdb_plugin.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/src/include/taler_merchantdb_plugin.h b/src/include/taler_merchantdb_plugin.h
index 594e3876..beeee462 100644
--- a/src/include/taler_merchantdb_plugin.h
+++ b/src/include/taler_merchantdb_plugin.h
@@ -1613,7 +1613,9 @@ struct TALER_MERCHANTDB_Plugin
* @param payto_uri what is the merchant's bank account that received the transfer
* @param wtid identifier of the wire transfer
* @param td transfer details to store
- * @return transaction status
+ * @return transaction status,
+ * #GNUNET_DB_STATUS_SUCCESS_NO_RESULTS if the @a wtid and @a exchange_uri are not known for this @a instance_id
+ * #GNUNET_DB_STATUS_SUCCESS_ONE_RESULT on success
*/
enum GNUNET_DB_QueryStatus
(*insert_transfer_details)(
@@ -1686,8 +1688,10 @@ struct TALER_MERCHANTDB_Plugin
* @param[out] total_amount amount that was debited from our
* aggregate balance at the exchange (in total, sum of
* the wire transfer amount and the @a wire_fee)
* @param[out] wire_fee the wire fee the exchange charged
* @param[out] execution_time when the transfer was executed by the exchange
* @param[out] verified did we confirm the transfer was OK
* @return transaction status
*/
@@ -1699,7 +1703,9 @@ struct TALER_MERCHANTDB_Plugin
const struct TALER_WireTransferIdentifierRawP *wtid,
struct TALER_Amount *total_amount,
struct TALER_Amount *wire_fee,
+ struct TALER_Amount *exchange_amount,
struct GNUNET_TIME_Absolute *execution_time,
+ bool *have_exchange_sig,
bool *verified);
@@ -1686,8 +1688,10 @@ struct TALER_MERCHANTDB_Plugin
* aggregate balance at the exchange (in total, sum of
* the wire transfer amount and the @a wire_fee)
- * @param[out] wire_fee the wire fee the exchange charged
- * @param[out] execution_time when the transfer was executed by the exchange
+ * @param[out] wire_fee the wire fee the exchange charged (only set if @a have_exchange_sig is true)
+ * @param[out] exchange_amount the amount the exchange claims was transferred (only set if @a have_exchange_sig is true)
+ * @param[out] execution_time when the transfer was executed by the exchange (only set if @a have_exchange_sig is true)
+ * @param[out] have_exchange_sig do we have a response from the exchange about this transfer
* @param[out] verified did we confirm the transfer was OK
* @return transaction status